use crate::{physics::Cartesian, physics::Polar, Camera, Doodad, Sprite};

pub struct System {
	bodies: Vec<Doodad>,
}

impl System {
	pub fn new() -> Self {
		let mut s = System { bodies: Vec::new() };

		s.bodies.push(Doodad {
			pos: Cartesian::new(0.0, 0.0),
			sprite: "a0".to_owned(),
		});

		s.bodies.push(Doodad {
			pos: Polar {
				center: Cartesian::new(0.0, 0.0),
				radius: 300.0,
				angle: 31.0,
			}
			.into(),
			sprite: "earth".to_owned(),
		});

		s.bodies.push(Doodad {
			pos: Cartesian::new(1000.0, 1000.0),
			sprite: "small".to_owned(),
		});

		return s;
	}

	pub fn sprites(&self, camera: &Camera) -> Vec<Sprite> {
		return self.bodies.iter().map(|x| x.sprite(camera)).collect();
	}
}
